@@ -635,7 +635,8 @@ matekbd_status_init (MatekbdStatus * gki)
 	gki->priv = g_new0 (MatekbdStatusPrivate, 1);
 
 	/* This should give NA a hint about the order */
-	gtk_status_icon_set_name (GTK_STATUS_ICON (gki), "keyboard");
+	/* commenting out fixes a Gdk-critical warning */
+/*	gtk_status_icon_set_name (GTK_STATUS_ICON (gki), "keyboard"); */
 
 	xkl_debug (100, "Initiating the widget startup process for %p\n",
 		   gki);
@@ -821,6 +822,11 @@ matekbd_status_new (void)
 	    GTK_STATUS_ICON (g_object_new (matekbd_status_get_type (), NULL));
 }
 
+/**
+ * matekbd_status_get_xkl_engine:
+ *
+ * Returns: (transfer none): The engine shared by all MatekbdStatus objects
+ */
 XklEngine *
 matekbd_status_get_xkl_engine ()
 {
@@ -829,6 +835,7 @@ matekbd_status_get_xkl_engine ()
 
 /**
  * matekbd_status_get_group_names:
+ *
  * Returns: (transfer none) (array zero-terminated=1): List of group names
  */
 gchar **
